@@ -2,8 +2,12 @@ import subprocess
 from .verdict import Response, Correct, WrongAnswer
 
 # Checker path, file paths to standard checker input
-def check(checker, judge_input, user_output, judge_output):
-    verdict = subprocess.run([checker, judge_input, user_output, judge_output], capture_output=True)
+def check(checker: str, judge_input, user_output, judge_output):
+    command_args = [checker, judge_input, user_output, judge_output]
+    if (checker.split('.').pop() == 'py'):
+        command_args.insert(0, 'python3')
+        
+    verdict = subprocess.run(command_args, capture_output=True)
 
     err = verdict.stderr.decode('utf-8')
     out = verdict.stdout.decode('utf-8')
